# Single

## First

red |  | green
| blue |
red |  | green

## Second

| blue |
red |  | green
| blue |

# Nested

red |  | green
| blue |
red |  | green
| blue |
red |  | green
| blue |
| blue |
red |  | green
| blue |
| blue |
red |  | green
| blue |
red |  | green
| blue |
red |  | green
| blue |
red |  | green
| blue |
red |  | green
| blue |
red |  | green
| blue |
red |  | green
| blue |
| blue |
red |  | green
| blue |